@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -64,6 +64,10 @@ __all__ = (
     "RecurringChargeTypeDef",
     "ReservedElasticsearchInstanceOfferingTypeDef",
     "ReservedElasticsearchInstanceTypeDef",
+    "ResponseMetadata",
+    "SAMLIdpTypeDef",
+    "SAMLOptionsInputTypeDef",
+    "SAMLOptionsOutputTypeDef",
     "ServiceSoftwareOptionsTypeDef",
     "SnapshotOptionsStatusTypeDef",
     "SnapshotOptionsTypeDef",
@@ -136,7 +140,11 @@ AdvancedSecurityOptionsStatusTypeDef = TypedDict(
 
 AdvancedSecurityOptionsTypeDef = TypedDict(
     "AdvancedSecurityOptionsTypeDef",
-    {"Enabled": bool, "InternalUserDatabaseEnabled": bool},
+    {
+        "Enabled": bool,
+        "InternalUserDatabaseEnabled": bool,
+        "SAMLOptions": "SAMLOptionsOutputTypeDef",
+    },
     total=False,
 )
 
@@ -165,6 +173,9 @@ DomainEndpointOptionsTypeDef = TypedDict(
     {
         "EnforceHTTPS": bool,
         "TLSSecurityPolicy": Literal["Policy-Min-TLS-1-0-2019-07", "Policy-Min-TLS-1-2-2019-07"],
+        "CustomEndpointEnabled": bool,
+        "CustomEndpoint": str,
+        "CustomEndpointCertificateArn": str,
     },
     total=False,
 )
@@ -741,6 +752,46 @@ ReservedElasticsearchInstanceTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+SAMLIdpTypeDef = TypedDict("SAMLIdpTypeDef", {"MetadataContent": str, "EntityId": str})
+
+SAMLOptionsInputTypeDef = TypedDict(
+    "SAMLOptionsInputTypeDef",
+    {
+        "Enabled": bool,
+        "Idp": "SAMLIdpTypeDef",
+        "MasterUserName": str,
+        "MasterBackendRole": str,
+        "SubjectKey": str,
+        "RolesKey": str,
+        "SessionTimeoutMinutes": int,
+    },
+    total=False,
+)
+
+SAMLOptionsOutputTypeDef = TypedDict(
+    "SAMLOptionsOutputTypeDef",
+    {
+        "Enabled": bool,
+        "Idp": "SAMLIdpTypeDef",
+        "SubjectKey": str,
+        "RolesKey": str,
+        "SessionTimeoutMinutes": int,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
 ServiceSoftwareOptionsTypeDef = TypedDict(
     "ServiceSoftwareOptionsTypeDef",
     {
@@ -837,6 +888,7 @@ AdvancedSecurityOptionsInputTypeDef = TypedDict(
         "Enabled": bool,
         "InternalUserDatabaseEnabled": bool,
         "MasterUserOptions": "MasterUserOptionsTypeDef",
+        "SAMLOptions": "SAMLOptionsInputTypeDef",
     },
     total=False,
 )
